# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rl_assistant.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import server_pb2 as server__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12rl_assistant.proto\x12\x04lugo\x1a\x0cserver.proto\"\x11\n\x0fRLSessionConfig\"}\n\x17PlayerOrdersOnRLSession\x12\"\n\tteam_side\x18\x01 \x01(\x0e\x32\x0f.lugo.Team.Side\x12\x0e\n\x06number\x18\x02 \x01(\r\x12\x11\n\tbehaviour\x18\x03 \x01(\t\x12\x1b\n\x06orders\x18\x04 \x03(\x0b\x32\x0b.lugo.Order\"a\n\rPlayersOrders\x12\x19\n\x11\x64\x65\x66\x61ult_behaviour\x18\x01 \x01(\t\x12\x35\n\x0eplayers_orders\x18\x02 \x03(\x0b\x32\x1d.lugo.PlayerOrdersOnRLSession\"\x8c\x01\n\x0bTurnOutcome\x12)\n\rgame_snapshot\x18\x01 \x01(\x0b\x32\x12.lugo.GameSnapshot\x12\x15\n\rscore_changed\x18\x02 \x01(\x08\x12\x1a\n\x12shot_clock_expired\x18\x03 \x01(\x08\x12\x1f\n\x17goal_zone_timer_expired\x18\x04 \x01(\x08\"\x0f\n\rRLResetConfig2\xbb\x01\n\x0bRLAssistant\x12;\n\x0cStartSession\x12\x15.lugo.RLSessionConfig\x1a\x12.lugo.GameSnapshot0\x01\x12;\n\x11SendPlayersOrders\x12\x13.lugo.PlayersOrders\x1a\x11.lugo.TurnOutcome\x12\x32\n\x08ResetEnv\x12\x13.lugo.RLResetConfig\x1a\x11.lugo.TurnOutcomeB#Z!github.com/lugobots/lugo4go/protob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'rl_assistant_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z!github.com/lugobots/lugo4go/proto'
  _RLSESSIONCONFIG._serialized_start=42
  _RLSESSIONCONFIG._serialized_end=59
  _PLAYERORDERSONRLSESSION._serialized_start=61
  _PLAYERORDERSONRLSESSION._serialized_end=186
  _PLAYERSORDERS._serialized_start=188
  _PLAYERSORDERS._serialized_end=285
  _TURNOUTCOME._serialized_start=288
  _TURNOUTCOME._serialized_end=428
  _RLRESETCONFIG._serialized_start=430
  _RLRESETCONFIG._serialized_end=445
  _RLASSISTANT._serialized_start=448
  _RLASSISTANT._serialized_end=635
# @@protoc_insertion_point(module_scope)
