# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: server.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import physics_pb2 as physics__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cserver.proto\x12\x04lugo\x1a\rphysics.proto\"\x8e\x01\n\x0bJoinRequest\x12\r\n\x05token\x18\x01 \x01(\t\x12\x18\n\x10protocol_version\x18\x02 \x01(\t\x12\"\n\tteam_side\x18\x03 \x01(\x0e\x32\x0f.lugo.Team.Side\x12\x0e\n\x06number\x18\x04 \x01(\r\x12\"\n\rinit_position\x18\x05 \x01(\x0b\x32\x0b.lugo.Point\"\xf4\x02\n\x0cGameSnapshot\x12\'\n\x05state\x18\x01 \x01(\x0e\x32\x18.lugo.GameSnapshot.State\x12\x0c\n\x04turn\x18\x02 \x01(\r\x12\x1d\n\thome_team\x18\x03 \x01(\x0b\x32\n.lugo.Team\x12\x1d\n\taway_team\x18\x04 \x01(\x0b\x32\n.lugo.Team\x12\x18\n\x04\x62\x61ll\x18\x05 \x01(\x0b\x32\n.lugo.Ball\x12\x1f\n\x17turns_ball_in_goal_zone\x18\x06 \x01(\r\x12#\n\nshot_clock\x18\x07 \x01(\x0b\x32\x0f.lugo.ShotClock\"\x8e\x01\n\x05State\x12\x0b\n\x07WAITING\x10\x00\x12\r\n\tGET_READY\x10\x01\x12\r\n\tLISTENING\x10\x02\x12\x0b\n\x07PLAYING\x10\x03\x12\x0c\n\x08SHIFTING\x10\x04\x12\x0c\n\x08THROW_IN\x10\x05\x12\x0f\n\x0b\x43ORNER_KICK\x10\x06\x12\x0b\n\x07PENALTY\x10\x07\x12\t\n\x05\x46\x41ULT\x10\x08\x12\x08\n\x04OVER\x10\x63\"}\n\x04Team\x12\x1d\n\x07players\x18\x01 \x03(\x0b\x32\x0c.lugo.Player\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05score\x18\x03 \x01(\r\x12\x1d\n\x04side\x18\x04 \x01(\x0e\x32\x0f.lugo.Team.Side\"\x1a\n\x04Side\x12\x08\n\x04HOME\x10\x00\x12\x08\n\x04\x41WAY\x10\x01\"H\n\tShotClock\x12\"\n\tteam_side\x18\x06 \x01(\x0e\x32\x0f.lugo.Team.Side\x12\x17\n\x0fremaining_turns\x18\x07 \x01(\r\"\xb5\x01\n\x06Player\x12\x0e\n\x06number\x18\x01 \x01(\r\x12\x1d\n\x08position\x18\x02 \x01(\x0b\x32\x0b.lugo.Point\x12 \n\x08velocity\x18\x03 \x01(\x0b\x32\x0e.lugo.Velocity\x12\"\n\tteam_side\x18\x04 \x01(\x0e\x32\x0f.lugo.Team.Side\x12\"\n\rinit_position\x18\x05 \x01(\x0b\x32\x0b.lugo.Point\x12\x12\n\nis_jumping\x18\x06 \x01(\x08\"e\n\x04\x42\x61ll\x12\x1d\n\x08position\x18\x01 \x01(\x0b\x32\x0b.lugo.Point\x12 \n\x08velocity\x18\x02 \x01(\x0b\x32\x0e.lugo.Velocity\x12\x1c\n\x06holder\x18\x03 \x01(\x0b\x32\x0c.lugo.Player\"\xab\x01\n\rOrderResponse\x12,\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x1e.lugo.OrderResponse.StatusCode\x12\x0f\n\x07\x64\x65tails\x18\x02 \x01(\t\"[\n\nStatusCode\x12\x0b\n\x07SUCCESS\x10\x00\x12\x12\n\x0eUNKNOWN_PLAYER\x10\x01\x12\x11\n\rNOT_LISTENING\x10\x02\x12\x0e\n\nWRONG_TURN\x10\x03\x12\t\n\x05OTHER\x10\x63\"L\n\x08OrderSet\x12\x0c\n\x04turn\x18\x01 \x01(\r\x12\x1b\n\x06orders\x18\x02 \x03(\x0b\x32\x0b.lugo.Order\x12\x15\n\rdebug_message\x18\x03 \x01(\t\"\x83\x01\n\x05Order\x12\x1a\n\x04move\x18\x01 \x01(\x0b\x32\n.lugo.MoveH\x00\x12\x1c\n\x05\x63\x61tch\x18\x02 \x01(\x0b\x32\x0b.lugo.CatchH\x00\x12\x1a\n\x04kick\x18\x03 \x01(\x0b\x32\n.lugo.KickH\x00\x12\x1a\n\x04jump\x18\x04 \x01(\x0b\x32\n.lugo.JumpH\x00\x42\x08\n\x06\x61\x63tion\"(\n\x04Move\x12 \n\x08velocity\x18\x01 \x01(\x0b\x32\x0e.lugo.Velocity\"\x07\n\x05\x43\x61tch\"(\n\x04Kick\x12 \n\x08velocity\x18\x01 \x01(\x0b\x32\x0e.lugo.Velocity\"(\n\x04Jump\x12 \n\x08velocity\x18\x01 \x01(\x0b\x32\x0e.lugo.Velocity2o\n\x04Game\x12\x34\n\tJoinATeam\x12\x11.lugo.JoinRequest\x1a\x12.lugo.GameSnapshot0\x01\x12\x31\n\nSendOrders\x12\x0e.lugo.OrderSet\x1a\x13.lugo.OrderResponseB#Z!github.com/lugobots/lugo4go/protob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'server_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z!github.com/lugobots/lugo4go/proto'
  _JOINREQUEST._serialized_start=38
  _JOINREQUEST._serialized_end=180
  _GAMESNAPSHOT._serialized_start=183
  _GAMESNAPSHOT._serialized_end=555
  _GAMESNAPSHOT_STATE._serialized_start=413
  _GAMESNAPSHOT_STATE._serialized_end=555
  _TEAM._serialized_start=557
  _TEAM._serialized_end=682
  _TEAM_SIDE._serialized_start=656
  _TEAM_SIDE._serialized_end=682
  _SHOTCLOCK._serialized_start=684
  _SHOTCLOCK._serialized_end=756
  _PLAYER._serialized_start=759
  _PLAYER._serialized_end=940
  _BALL._serialized_start=942
  _BALL._serialized_end=1043
  _ORDERRESPONSE._serialized_start=1046
  _ORDERRESPONSE._serialized_end=1217
  _ORDERRESPONSE_STATUSCODE._serialized_start=1126
  _ORDERRESPONSE_STATUSCODE._serialized_end=1217
  _ORDERSET._serialized_start=1219
  _ORDERSET._serialized_end=1295
  _ORDER._serialized_start=1298
  _ORDER._serialized_end=1429
  _MOVE._serialized_start=1431
  _MOVE._serialized_end=1471
  _CATCH._serialized_start=1473
  _CATCH._serialized_end=1480
  _KICK._serialized_start=1482
  _KICK._serialized_end=1522
  _JUMP._serialized_start=1524
  _JUMP._serialized_end=1564
  _GAME._serialized_start=1566
  _GAME._serialized_end=1677
# @@protoc_insertion_point(module_scope)
