# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: broadcast.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import server_pb2 as server__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x62roadcast.proto\x12\x04lugo\x1a\x0cserver.proto\"\x1e\n\x0eWatcherRequest\x12\x0c\n\x04uuid\x18\x01 \x01(\t\"$\n\x0cStartRequest\x12\x14\n\x0cwatcher_uuid\x18\x01 \x01(\t\"\xfa\x02\n\tGameEvent\x12)\n\rgame_snapshot\x18\x01 \x01(\x0b\x32\x12.lugo.GameSnapshot\x12*\n\nnew_player\x18\x02 \x01(\x0b\x32\x14.lugo.EventNewPlayerH\x00\x12,\n\x0blost_player\x18\x03 \x01(\x0b\x32\x15.lugo.EventLostPlayerH\x00\x12.\n\x0cstate_change\x18\x04 \x01(\x0b\x32\x16.lugo.EventStateChangeH\x00\x12\x1f\n\x04goal\x18\x05 \x01(\x0b\x32\x0f.lugo.EventGoalH\x00\x12(\n\tgame_over\x18\x06 \x01(\x0b\x32\x13.lugo.EventGameOverH\x00\x12\x30\n\nbreakpoint\x18\x07 \x01(\x0b\x32\x1a.lugo.EventDebugBreakpointH\x00\x12\x32\n\x0e\x64\x65\x62ug_released\x18\x08 \x01(\x0b\x32\x18.lugo.EventDebugReleasedH\x00\x42\x07\n\x05\x65vent\"\xfa\x02\n\tGameSetup\x12\x18\n\x10protocol_version\x18\x01 \x01(\t\x12\x10\n\x08\x64\x65v_mode\x18\x02 \x01(\x08\x12\x30\n\nstart_mode\x18\x03 \x01(\x0e\x32\x1c.lugo.GameSetup.StartingMode\x12\x35\n\x0elistening_mode\x18\x04 \x01(\x0e\x32\x1d.lugo.GameSetup.ListeningMode\x12\x1a\n\x12listening_duration\x18\x05 \x01(\r\x12\x15\n\rgame_duration\x18\x06 \x01(\r\x12%\n\thome_team\x18\x08 \x01(\x0b\x32\x12.lugo.TeamSettings\x12%\n\taway_team\x18\t \x01(\x0b\x32\x12.lugo.TeamSettings\"%\n\x0cStartingMode\x12\x0b\n\x07NO_WAIT\x10\x00\x12\x08\n\x04WAIT\x10\x01\"0\n\rListeningMode\x12\t\n\x05TIMER\x10\x00\x12\x08\n\x04RUSH\x10\x01\x12\n\n\x06REMOTE\x10\x02\"N\n\x0cTeamSettings\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06\x61vatar\x18\x02 \x01(\t\x12 \n\x06\x63olors\x18\x03 \x01(\x0b\x32\x10.lugo.TeamColors\"R\n\nTeamColors\x12 \n\x07primary\x18\x01 \x01(\x0b\x32\x0f.lugo.TeamColor\x12\"\n\tsecondary\x18\x02 \x01(\x0b\x32\x0f.lugo.TeamColor\"5\n\tTeamColor\x12\x0b\n\x03red\x18\x01 \x01(\r\x12\r\n\x05green\x18\x02 \x01(\r\x12\x0c\n\x04\x62lue\x18\x04 \x01(\r\".\n\x0e\x45ventNewPlayer\x12\x1c\n\x06player\x18\x01 \x01(\x0b\x32\x0c.lugo.Player\"/\n\x0f\x45ventLostPlayer\x12\x1c\n\x06player\x18\x01 \x01(\x0b\x32\x0c.lugo.Player\"q\n\x10\x45ventStateChange\x12\x30\n\x0eprevious_state\x18\x01 \x01(\x0e\x32\x18.lugo.GameSnapshot.State\x12+\n\tnew_state\x18\x02 \x01(\x0e\x32\x18.lugo.GameSnapshot.State\"*\n\tEventGoal\x12\x1d\n\x04side\x18\x01 \x01(\x0e\x32\x0f.lugo.Team.Side\"\xa7\x02\n\rEventGameOver\x12\x30\n\x06reason\x18\x01 \x01(\x0e\x32 .lugo.EventGameOver.EndingReason\x12,\n\x05\x62lame\x18\x02 \x01(\x0e\x32\x1d.lugo.EventGameOver.BlameStop\"o\n\x0c\x45ndingReason\x12\x10\n\x0cTIME_IS_OVER\x10\x00\x12\x13\n\x0fWAITING_EXPIRED\x10\x01\x12\x14\n\x10NO_ENOUGH_PLAYER\x10\x02\x12\x14\n\x10\x45XTERNAL_REQUEST\x10\x03\x12\x0c\n\x08KNOCKOUT\x10\x04\"E\n\tBlameStop\x12\n\n\x06NORMAL\x10\x00\x12\x0e\n\nBOTH_TEAMS\x10\x01\x12\r\n\tHOME_TEAM\x10\x02\x12\r\n\tAWAY_TEAM\x10\x03\"u\n\x14\x45ventDebugBreakpoint\x12\x39\n\nbreakpoint\x18\x01 \x01(\x0e\x32%.lugo.EventDebugBreakpoint.Breakpoint\"\"\n\nBreakpoint\x12\n\n\x06ORDERS\x10\x00\x12\x08\n\x04TURN\x10\x01\"\x14\n\x12\x45ventDebugReleased2\xa8\x01\n\tBroadcast\x12\x32\n\x07OnEvent\x12\x14.lugo.WatcherRequest\x1a\x0f.lugo.GameEvent0\x01\x12\x35\n\x0cGetGameSetup\x12\x14.lugo.WatcherRequest\x1a\x0f.lugo.GameSetup\x12\x30\n\tStartGame\x12\x12.lugo.StartRequest\x1a\x0f.lugo.GameSetupB#Z!github.com/lugobots/lugo4go/protob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'broadcast_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z!github.com/lugobots/lugo4go/proto'
  _WATCHERREQUEST._serialized_start=39
  _WATCHERREQUEST._serialized_end=69
  _STARTREQUEST._serialized_start=71
  _STARTREQUEST._serialized_end=107
  _GAMEEVENT._serialized_start=110
  _GAMEEVENT._serialized_end=488
  _GAMESETUP._serialized_start=491
  _GAMESETUP._serialized_end=869
  _GAMESETUP_STARTINGMODE._serialized_start=782
  _GAMESETUP_STARTINGMODE._serialized_end=819
  _GAMESETUP_LISTENINGMODE._serialized_start=821
  _GAMESETUP_LISTENINGMODE._serialized_end=869
  _TEAMSETTINGS._serialized_start=871
  _TEAMSETTINGS._serialized_end=949
  _TEAMCOLORS._serialized_start=951
  _TEAMCOLORS._serialized_end=1033
  _TEAMCOLOR._serialized_start=1035
  _TEAMCOLOR._serialized_end=1088
  _EVENTNEWPLAYER._serialized_start=1090
  _EVENTNEWPLAYER._serialized_end=1136
  _EVENTLOSTPLAYER._serialized_start=1138
  _EVENTLOSTPLAYER._serialized_end=1185
  _EVENTSTATECHANGE._serialized_start=1187
  _EVENTSTATECHANGE._serialized_end=1300
  _EVENTGOAL._serialized_start=1302
  _EVENTGOAL._serialized_end=1344
  _EVENTGAMEOVER._serialized_start=1347
  _EVENTGAMEOVER._serialized_end=1642
  _EVENTGAMEOVER_ENDINGREASON._serialized_start=1460
  _EVENTGAMEOVER_ENDINGREASON._serialized_end=1571
  _EVENTGAMEOVER_BLAMESTOP._serialized_start=1573
  _EVENTGAMEOVER_BLAMESTOP._serialized_end=1642
  _EVENTDEBUGBREAKPOINT._serialized_start=1644
  _EVENTDEBUGBREAKPOINT._serialized_end=1761
  _EVENTDEBUGBREAKPOINT_BREAKPOINT._serialized_start=1727
  _EVENTDEBUGBREAKPOINT_BREAKPOINT._serialized_end=1761
  _EVENTDEBUGRELEASED._serialized_start=1763
  _EVENTDEBUGRELEASED._serialized_end=1783
  _BROADCAST._serialized_start=1786
  _BROADCAST._serialized_end=1954
# @@protoc_insertion_point(module_scope)
